<?php

namespace Drupal\outlayer\Plugin\views\style;

use Drupal\gridstack\Plugin\views\style\GridStackViews;
use Drupal\outlayer\OutlayerDefault;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Outlayer base style plugin for Isotope and Grid.
 */
class OutlayerViewsGridStack extends GridStackViews {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->manager = $container->get('outlayer.manager');
    $instance->blazyManager = $instance->blazyManager ?? $container->get('blazy.manager');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function admin() {
    return \Drupal::service('outlayer.admin');
  }

  /**
   * Provides commons settings for the style plugins.
   */
  protected function buildSettings() {
    $settings = parent::buildSettings();
    $settings += OutlayerDefault::htmlSettings();
    $blazies = $settings['blazies'];
    $outlayers = $settings['outlayers'];
    $instance = $blazies->get('view.name') . '-' . $blazies->get('view.view_mode');
    $instance = str_replace('_', '-', $instance);

    $outlayers->set('view.base_id', $instance);

    return $settings;
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = [];
    $settings = OutlayerDefault::gridSettings() + OutlayerDefault::viewsSettings();
    foreach ($settings as $key => $value) {
      $options[$key] = ['default' => $value];
    }
    return $options + parent::defineOptions();
  }

}
